@@ -62,7 +62,7 @@ msk.morphol.1998.create <- function(language     = "English",
   # node "Wasserspiegelbreitenvariabilitaet":
   # -----------------------------------------
   
-  # Wasserspiegelbreitenvariabilitaet (discrete attribute):
+  # Wasserspiegelbreitenvariabilitaet:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_widthvar_class_high",dict),
                        ecoval.translate("L_morphol_widthvar_class_moderate",dict),
@@ -90,61 +90,7 @@ msk.morphol.1998.create <- function(language     = "English",
   pnt100_riprap <- 2.375  # upper end of the yellow class
   pnt100_other  <- 3.0
   
-  # Sohlenverbauung Steinschuettung, Rauhbett (attribute range 0 - 100):
-  
-  bedmod_cont_riprap <-
-    utility.endnode.intpol1d.create(
-      name.node   = ecoval.translate("N_morphol_bedmod_cont_riprap",dict),
-      name.attrib = ecoval.translate("A_morphol_bedmod_fract_percent",dict),
-      range       = c(0,100),
-      x           = c(0,10,100),
-      u           = c(pnt2val(pnt0),
-                      pnt2val(pnt10),
-                      pnt2val(pnt100_riprap)),
-      required    = FALSE,
-      utility     = FALSE,
-      col         = col)
-  
-  # Sohlenverbauung andere Materialien (attribute range 0 - 100):
-  
-  bedmod_cont_other <-
-    utility.endnode.intpol1d.create(
-      name.node   = ecoval.translate("N_morphol_bedmod_cont_other",dict),
-      name.attrib = ecoval.translate("A_morphol_bedmod_fract_percent",dict),
-      range       = c(0,100),
-      x           = c(0,10,30,100),
-      u           = c(pnt2val(pnt0),
-                      pnt2val(pnt10),
-                      pnt2val(pnt30_other),
-                      pnt2val(pnt100_other)),
-      required    = FALSE,
-      utility     = FALSE,
-      col         = col)
-  
-  # Sohlenverbauung (attribute range 0 - 100):
-  
-  comb <- data.frame(c(ecoval.translate("L_morphol_bedmod_type_class_riprap1",dict),
-                       ecoval.translate("L_morphol_bedmod_type_class_riprap2",dict),
-                       ecoval.translate("L_morphol_bedmod_type_class_riprap3",dict),
-                       ecoval.translate("L_morphol_bedmod_type_class_riprap4",dict),
-                       ecoval.translate("L_morphol_bedmod_type_class_riprap5",dict),
-                       ecoval.translate("L_morphol_bedmod_type_class_other1",dict),
-                       ecoval.translate("L_morphol_bedmod_type_class_other2",dict),
-                       ecoval.translate("L_morphol_bedmod_type_class_other3",dict),
-                       ecoval.translate("L_morphol_bedmod_type_class_other4",dict),
-                       ecoval.translate("L_morphol_bedmod_type_class_other5",dict)))
-  colnames(comb) <- ecoval.translate("A_morphol_bedmod_type_class",dict)
-  bedmod_cont <-
-    utility.endnode.cond.create(
-      name.node     = ecoval.translate("N_morphol_bedmod_cont",dict),
-      attrib.levels = comb,
-      nodes         = list(bedmod_cont_riprap,bedmod_cont_riprap,bedmod_cont_riprap,bedmod_cont_riprap,bedmod_cont_riprap,
-                           bedmod_cont_other,bedmod_cont_other,bedmod_cont_other,bedmod_cont_other,bedmod_cont_other),
-      required      = FALSE,
-      utility       = FALSE,
-      col           = col)
-  
-  # Sohlenverbauung rip-rap (discrete attribute):
+  # Sohlenverbauung rip-rap:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_bedmod_fract_class_0",dict),
                        ecoval.translate("L_morphol_bedmod_fract_class_0to10",dict),
@@ -154,9 +100,9 @@ msk.morphol.1998.create <- function(language     = "English",
                        ecoval.translate("L_morphol_bedmod_fract_class_60to100",dict),
                        ecoval.translate("L_morphol_bedmod_fract_class_100",dict)))
   colnames(comb) <- ecoval.translate("A_morphol_bedmod_fract_class",dict)
-  bedmod_discr_riprap <-
+  bedmod_riprap <-
     utility.endnode.discrete.create(
-      name.node     = ecoval.translate("N_morphol_bedmod_discr_riprap",dict),
+      name.node     = ecoval.translate("N_morphol_bedmod_riprap",dict),
       attrib.levels = comb,
       u             = c(pnt2val(0),      #0
                         pnt2val(1),      #0-10
@@ -169,7 +115,7 @@ msk.morphol.1998.create <- function(language     = "English",
       utility       = FALSE,
       col           = col)
   
-  # Sohlenverbauung other (discrete attribute):
+  # Sohlenverbauung other:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_bedmod_fract_class_0",dict),
                        ecoval.translate("L_morphol_bedmod_fract_class_0to10",dict),
@@ -179,9 +125,9 @@ msk.morphol.1998.create <- function(language     = "English",
                        ecoval.translate("L_morphol_bedmod_fract_class_60to100",dict),
                        ecoval.translate("L_morphol_bedmod_fract_class_100",dict)))
   colnames(comb) <- ecoval.translate("A_morphol_bedmod_fract_class",dict)
-  bedmod_discr_other <-
+  bedmod_other <-
     utility.endnode.discrete.create(
-      name.node     = ecoval.translate("N_morphol_bedmod_discr_other",dict),
+      name.node     = ecoval.translate("N_morphol_bedmod_other",dict),
       attrib.levels = comb,
       u             = c(pnt2val(0),  #0
                         pnt2val(1),  #0-10
@@ -194,7 +140,7 @@ msk.morphol.1998.create <- function(language     = "English",
       utility       = FALSE,
       col           = col)
   
-  # Sohlenverbauung (discrete attribute):
+  # Sohlenverbauung:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_bedmod_type_class_riprap1",dict),
                        ecoval.translate("L_morphol_bedmod_type_class_riprap2",dict),
@@ -207,26 +153,16 @@ msk.morphol.1998.create <- function(language     = "English",
                        ecoval.translate("L_morphol_bedmod_type_class_other4",dict),
                        ecoval.translate("L_morphol_bedmod_type_class_other5",dict)))
   colnames(comb) <- ecoval.translate("A_morphol_bedmod_type_class",dict)
-  bedmod_discr <-
+  bedmod <-
     utility.endnode.cond.create(
-      name.node     = ecoval.translate("N_morphol_bedmod_discr",dict),
+      name.node     = ecoval.translate("N_morphol_bedmod",dict),
       attrib.levels = comb,
-      nodes         = list(bedmod_discr_riprap,bedmod_discr_riprap,bedmod_discr_riprap,bedmod_discr_riprap,bedmod_discr_riprap,
-                           bedmod_discr_other,bedmod_discr_other,bedmod_discr_other,bedmod_discr_other,bedmod_discr_other),
-      required      = FALSE,
+      nodes         = list(bedmod_riprap,bedmod_riprap,bedmod_riprap,bedmod_riprap,bedmod_riprap,
+                           bedmod_other,bedmod_other,bedmod_other,bedmod_other,bedmod_other),
+      required      = TRUE,
       utility       = FALSE,
       col           = col)
   
-  # Sohlenverbauung:
-  
-  bedmod <-
-    utility.endnode.firstavail.create(
-      name.node = ecoval.translate("N_morphol_bedmod",dict),
-      nodes     = list(bedmod_cont,bedmod_discr),
-      required  = TRUE,
-      utility   = FALSE,
-      col       = col)
-  
   # node "Boeschungsfussverbauung":
   # -------------------------------
   
@@ -244,41 +180,7 @@ msk.morphol.1998.create <- function(language     = "English",
   pnt60_imperm  <- 2.5
   pnt100_imperm <- 3.0
   
-  # Boeschungsfussverbauung left permeable (attribute range 0 - 100)
-  
-  bankmod_left_cont_perm <-
-    utility.endnode.intpol1d.create(
-      name.node   = ecoval.translate("N_morphol_bankmod_left_cont_perm",dict),
-      name.attrib = ecoval.translate("A_morphol_bankmod_fract_left_percent",dict),
-      range       = c(0,100),
-      x           = c(0,10,30,60,100),
-      u           = c(pnt2val(pnt0_perm),
-                      pnt2val(pnt10_perm),
-                      pnt2val(pnt30_perm),
-                      pnt2val(pnt60_perm),
-                      pnt2val(pnt100_perm)),
-      required    = FALSE,
-      utility       = FALSE,
-      col           = col)
-  
-  # Boeschungsfussverbauung right permeable (attribute range 0 - 100)
-  
-  bankmod_right_cont_perm <-
-    utility.endnode.intpol1d.create(
-      name.node   = ecoval.translate("N_morphol_bankmod_right_cont_perm",dict),
-      name.attrib = ecoval.translate("A_morphol_bankmod_fract_right_percent",dict),
-      range       = c(0,100),
-      x           = c(0,10,30,60,100),
-      u           = c(pnt2val(pnt0_perm),
-                      pnt2val(pnt10_perm),
-                      pnt2val(pnt30_perm),
-                      pnt2val(pnt60_perm),
-                      pnt2val(pnt100_perm)),
-      required      = FALSE,
-      utility       = FALSE,
-      col           = col)
-  
-  # Boeschungsfussverbauung left permeable (discrete attribute range)
+  # Boeschungsfussverbauung left permeable:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_bankmod_fract_class_0",dict),
                        ecoval.translate("L_morphol_bankmod_fract_class_0to10",dict),
@@ -287,9 +189,9 @@ msk.morphol.1998.create <- function(language     = "English",
                        ecoval.translate("L_morphol_bankmod_fract_class_60to100",dict),
                        ecoval.translate("L_morphol_bankmod_fract_class_100",dict)))
   colnames(comb) <- ecoval.translate("A_morphol_bankmod_fract_left_class",dict)
-  bankmod_left_discr_perm <-
+  bankmod_left_perm <-
     utility.endnode.discrete.create(
-      name.node     = ecoval.translate("N_morphol_bankmod_left_discr_perm",dict),
+      name.node     = ecoval.translate("N_morphol_bankmod_left_perm",dict),
       attrib.levels = comb,
       u             = c(pnt2val(0),
                         pnt2val(0),
@@ -301,7 +203,7 @@ msk.morphol.1998.create <- function(language     = "English",
       utility       = FALSE,
       col           = col)
   
-  # Boeschungsfussverbauung right permeable (discrete attribute range)
+  # Boeschungsfussverbauung right permeable:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_bankmod_fract_class_0",dict),
                        ecoval.translate("L_morphol_bankmod_fract_class_0to10",dict),
@@ -310,9 +212,9 @@ msk.morphol.1998.create <- function(language     = "English",
                        ecoval.translate("L_morphol_bankmod_fract_class_60to100",dict),
                        ecoval.translate("L_morphol_bankmod_fract_class_100",dict)))
   colnames(comb) <- ecoval.translate("A_morphol_bankmod_fract_right_class",dict)
-  bankmod_right_discr_perm <-
+  bankmod_right_perm <-
     utility.endnode.discrete.create(
-      name.node     = ecoval.translate("N_morphol_bankmod_right_discr_perm",dict),
+      name.node     = ecoval.translate("N_morphol_bankmod_right_perm",dict),
       attrib.levels = comb,
       u             = c(pnt2val(0),
                         pnt2val(0),
@@ -324,41 +226,7 @@ msk.morphol.1998.create <- function(language     = "English",
       utility       = FALSE,
       col           = col)
   
-  # Boeschungsfussverbauung left impermeable (continuous, attribute range 0 - 100)
-  
-  bankmod_left_cont_imperm <-
-    utility.endnode.intpol1d.create(
-      name.node   = ecoval.translate("N_morphol_bankmod_left_cont_imperm",dict),
-      name.attrib = ecoval.translate("A_morphol_bankmod_fract_left_percent",dict),
-      range       = c(0,100),
-      x           = c(0,10,30,60,100),
-      u           = c(pnt2val(pnt0_imperm),
-                      pnt2val(pnt10_imperm),
-                      pnt2val(pnt30_imperm),
-                      pnt2val(pnt60_imperm),
-                      pnt2val(pnt100_imperm)),
-      required    = FALSE,
-      utility     = FALSE,
-      col         = col)
-  
-  # Boeschungsfussverbauung right impermeable (continous, attribute range 0 - 100)
-  
-  bankmod_right_cont_imperm <-
-    utility.endnode.intpol1d.create(
-      name.node   = ecoval.translate("N_morphol_bankmod_right_cont_imperm",dict),
-      name.attrib = ecoval.translate("A_morphol_bankmod_fract_right_percent",dict),
-      range       = c(0,100),
-      x           = c(0,10,30,60,100),
-      u           = c(pnt2val(pnt0_imperm),
-                      pnt2val(pnt10_imperm),
-                      pnt2val(pnt30_imperm),
-                      pnt2val(pnt60_imperm),
-                      pnt2val(pnt100_imperm)),
-      required    = FALSE,
-      utility     = FALSE,
-      col         = col)
-  
-  # Boeschungsfussverbauung left impermeable (discrete attribute range)
+  # Boeschungsfussverbauung left impermeable:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_bankmod_fract_class_0",dict),
                        ecoval.translate("L_morphol_bankmod_fract_class_0to10",dict),
@@ -367,9 +235,9 @@ msk.morphol.1998.create <- function(language     = "English",
                        ecoval.translate("L_morphol_bankmod_fract_class_60to100",dict),
                        ecoval.translate("L_morphol_bankmod_fract_class_100",dict)))
   colnames(comb) <- ecoval.translate("A_morphol_bankmod_fract_left_class",dict)
-  bankmod_left_discr_imperm <-
+  bankmod_left_imperm <-
     utility.endnode.discrete.create(
-      name.node     = ecoval.translate("N_morphol_bankmod_left_discr_imperm",dict),
+      name.node     = ecoval.translate("N_morphol_bankmod_left_imperm",dict),
       attrib.levels = comb,
       u             = c(pnt2val(0),
                         pnt2val(0),
@@ -381,7 +249,7 @@ msk.morphol.1998.create <- function(language     = "English",
       utility       = FALSE,
       col           = col)
   
-  # Boeschungsfussverbauung right impermeable (discrete attribute range)
+  # Boeschungsfussverbauung right impermeable:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_bankmod_fract_class_0",dict),
                        ecoval.translate("L_morphol_bankmod_fract_class_0to10",dict),
@@ -390,9 +258,9 @@ msk.morphol.1998.create <- function(language     = "English",
                        ecoval.translate("L_morphol_bankmod_fract_class_60to100",dict),
                        ecoval.translate("L_morphol_bankmod_fract_class_100",dict)))
   colnames(comb) <- ecoval.translate("A_morphol_bankmod_fract_right_class",dict)
-  bankmod_right_discr_imperm <-
+  bankmod_right_imperm <-
     utility.endnode.discrete.create(
-      name.node     = ecoval.translate("N_morphol_bankmod_right_discr_imperm",dict),
+      name.node     = ecoval.translate("N_morphol_bankmod_right_imperm",dict),
       attrib.levels = comb,
       u             = c(pnt2val(0),
                         pnt2val(0),
@@ -404,7 +272,7 @@ msk.morphol.1998.create <- function(language     = "English",
       utility       = FALSE,
       col           = col)
   
-  # Boeschungsfussverbauung left cont
+  # Boeschungsfussverbauung left:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_bankmod_perm_class_perm1",dict),
                        ecoval.translate("L_morphol_bankmod_perm_class_perm2",dict),
@@ -417,138 +285,56 @@ msk.morphol.1998.create <- function(language     = "English",
                        ecoval.translate("L_morphol_bankmod_perm_class_imperm4",dict),
                        ecoval.translate("L_morphol_bankmod_perm_class_imperm5",dict)))
   colnames(comb) <- ecoval.translate("A_morphol_bankmod_perm_left_class",dict)
-  bankmod_left_cont <-
-    utility.endnode.cond.create(
-      name.node     = ecoval.translate("N_morphol_bankmod_left_cont",dict),
-      attrib.levels = comb,
-      nodes         = list(bankmod_left_cont_perm,
-                           bankmod_left_cont_perm,
-                           bankmod_left_cont_perm,
-                           bankmod_left_cont_perm,
-                           bankmod_left_cont_perm,
-                           bankmod_left_cont_imperm,
-                           bankmod_left_cont_imperm,
-                           bankmod_left_cont_imperm,
-                           bankmod_left_cont_imperm,
-                           bankmod_left_cont_imperm),
-      required      = FALSE,
-      utility       = FALSE,
-      col           = col)
-  
-  # Boeschungsfussverbauung right cont
-  
-  comb <- data.frame(c(ecoval.translate("L_morphol_bankmod_perm_class_perm1",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm2",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm3",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm4",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm5",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm1",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm2",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm3",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm4",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm5",dict)))
-  colnames(comb) <- ecoval.translate("A_morphol_bankmod_perm_right_class",dict)
-  bankmod_right_cont <-
-    utility.endnode.cond.create(
-      name.node     = ecoval.translate("N_morphol_bankmod_right_cont",dict),
-      attrib.levels = comb,
-      nodes         = list(bankmod_right_cont_perm,
-                           bankmod_right_cont_perm,
-                           bankmod_right_cont_perm,
-                           bankmod_right_cont_perm,
-                           bankmod_right_cont_perm,
-                           bankmod_right_cont_imperm,
-                           bankmod_right_cont_imperm,
-                           bankmod_right_cont_imperm,
-                           bankmod_right_cont_imperm,
-                           bankmod_right_cont_imperm),
-      required      = FALSE,
-      utility       = FALSE,
-      col           = col)
-  
-  # Boeschungsfussverbauung left discr
-  
-  comb <- data.frame(c(ecoval.translate("L_morphol_bankmod_perm_class_perm1",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm2",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm3",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm4",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm5",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm1",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm2",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm3",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm4",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm5",dict)))
-  colnames(comb) <- ecoval.translate("A_morphol_bankmod_perm_left_class",dict)
-  bankmod_left_discr <-
-    utility.endnode.cond.create(
-      name.node     = ecoval.translate("N_morphol_bankmod_left_discr",dict),
-      attrib.levels = comb,
-      nodes         = list(bankmod_left_discr_perm,
-                           bankmod_left_discr_perm,
-                           bankmod_left_discr_perm,
-                           bankmod_left_discr_perm,
-                           bankmod_left_discr_perm,
-                           bankmod_left_discr_imperm,
-                           bankmod_left_discr_imperm,
-                           bankmod_left_discr_imperm,
-                           bankmod_left_discr_imperm,
-                           bankmod_left_discr_imperm),
-      required      = FALSE,
-      utility       = FALSE,
-      col           = col)
-  
-  # Boeschungsfussverbauung right discr
-  
-  comb <- data.frame(c(ecoval.translate("L_morphol_bankmod_perm_class_perm1",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm2",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm3",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm4",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_perm5",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm1",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm2",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm3",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm4",dict),
-                       ecoval.translate("L_morphol_bankmod_perm_class_imperm5",dict)))
-  colnames(comb) <- ecoval.translate("A_morphol_bankmod_perm_right_class",dict)
-  bankmod_right_discr <-
-    utility.endnode.cond.create(
-      name.node     = ecoval.translate("N_morphol_bankmod_right_discr",dict),
-      attrib.levels = comb,
-      nodes         = list(bankmod_right_discr_perm,
-                           bankmod_right_discr_perm,
-                           bankmod_right_discr_perm,
-                           bankmod_right_discr_perm,
-                           bankmod_right_discr_perm,
-                           bankmod_right_discr_imperm,
-                           bankmod_right_discr_imperm,
-                           bankmod_right_discr_imperm,
-                           bankmod_right_discr_imperm,
-                           bankmod_right_discr_imperm),
-      required      = FALSE,
-      utility       = FALSE,
-      col           = col)
-  
-  # Boeschungsfussverbauung left
-  
   bankmod_left <-
-    utility.endnode.firstavail.create(
-      name.node = ecoval.translate("N_morphol_bankmod_left",dict),
-      nodes     = list(bankmod_left_cont,bankmod_left_discr),
-      required  = FALSE,
-      utility   = FALSE,
-      col       = col)
+    utility.endnode.cond.create(
+      name.node     = ecoval.translate("N_morphol_bankmod_left",dict),
+      attrib.levels = comb,
+      nodes         = list(bankmod_left_perm,
+                           bankmod_left_perm,
+                           bankmod_left_perm,
+                           bankmod_left_perm,
+                           bankmod_left_perm,
+                           bankmod_left_imperm,
+                           bankmod_left_imperm,
+                           bankmod_left_imperm,
+                           bankmod_left_imperm,
+                           bankmod_left_imperm),
+      required      = FALSE,
+      utility       = FALSE,
+      col           = col)
   
-  # Boeschungsfussverbauung right
+  # Boeschungsfussverbauung right:
   
+  comb <- data.frame(c(ecoval.translate("L_morphol_bankmod_perm_class_perm1",dict),
+                       ecoval.translate("L_morphol_bankmod_perm_class_perm2",dict),
+                       ecoval.translate("L_morphol_bankmod_perm_class_perm3",dict),
+                       ecoval.translate("L_morphol_bankmod_perm_class_perm4",dict),
+                       ecoval.translate("L_morphol_bankmod_perm_class_perm5",dict),
+                       ecoval.translate("L_morphol_bankmod_perm_class_imperm1",dict),
+                       ecoval.translate("L_morphol_bankmod_perm_class_imperm2",dict),
+                       ecoval.translate("L_morphol_bankmod_perm_class_imperm3",dict),
+                       ecoval.translate("L_morphol_bankmod_perm_class_imperm4",dict),
+                       ecoval.translate("L_morphol_bankmod_perm_class_imperm5",dict)))
+  colnames(comb) <- ecoval.translate("A_morphol_bankmod_perm_right_class",dict)
   bankmod_right <-
-    utility.endnode.firstavail.create(
-      name.node = ecoval.translate("N_morphol_bankmod_right",dict),
-      nodes     = list(bankmod_right_cont,bankmod_right_discr),
-      required  = FALSE,
-      utility   = FALSE,
-      col       = col)
+    utility.endnode.cond.create(
+      name.node     = ecoval.translate("N_morphol_bankmod_right",dict),
+      attrib.levels = comb,
+      nodes         = list(bankmod_right_perm,
+                           bankmod_right_perm,
+                           bankmod_right_perm,
+                           bankmod_right_perm,
+                           bankmod_right_perm,
+                           bankmod_right_imperm,
+                           bankmod_right_imperm,
+                           bankmod_right_imperm,
+                           bankmod_right_imperm,
+                           bankmod_right_imperm),
+      required      = FALSE,
+      utility       = FALSE,
+      col           = col)
   
-  # Boeschungsfussverbauung
+  # Boeschungsfussverbauung:
   
   bankmod <-
     utility.aggregation.create(
@@ -562,115 +348,118 @@ msk.morphol.1998.create <- function(language     = "English",
   # node "Uferbereich":
   # -------------------
   
-  # Uferbereichsbreite left width widthvar=high
+  max.riverwidth      <- 100
+  max.ripparzonewidth <- 200
+
+    # Uferbereichsbreite left width widthvar=high:
   
   riparzone_left_width_highvar <-
     utility.endnode.intpol2d.create(
       name.node   = ecoval.translate("N_morphol_riparzone_left_width_highvar",dict),
       name.attrib = c(ecoval.translate("A_morphol_riverbed_width_m",dict),
                       ecoval.translate("A_morphol_riparzone_width_left_m",dict)),
-      ranges      = list(c(0,16),c(0,30)),
-      isolines    = list(list(x=c(0,16),y=c(0,0)),
-                         list(x=c(0,2,15,16),y=c(5,5,15,15)),
-                         list(x=c(0,16),y=c(15,15)),
-                         list(x=c(0,16),y=c(30,30))),
+      ranges      = list(c(0,max.riverwidth),c(0,max.ripparzonewidth)),
+      isolines    = list(list(x=c(0,max.riverwidth),y=c(0,0)),
+                         list(x=c(0,2,15,max.riverwidth),y=c(5,5,15,15)),
+                         list(x=c(0,max.riverwidth),y=c(15,15)),
+                         list(x=c(0,max.riverwidth),y=c(max.ripparzonewidth,max.ripparzonewidth))),
       u           = c(0.0,0.6,1.0,1.0),
       lead        = 1,
       utility     = FALSE,
       required    = FALSE,
       col         = col)
   
-  # Uferbereichsbreite left width widthvar=moderate
+  # Uferbereichsbreite left width widthvar=moderate:
   
   riparzone_left_width_moderatevar <-
     utility.endnode.intpol2d.create(
       name.node   = ecoval.translate("N_morphol_riparzone_left_width_moderatevar",dict),
       name.attrib = c(ecoval.translate("A_morphol_riverbed_width_m",dict),
                       ecoval.translate("A_morphol_riparzone_width_left_m",dict)),
-      ranges      = list(c(0,16),c(0,30)),
-      isolines    = list(list(x=c(0,16),y=c(0,0)),
-                         list(x=c(0,1.5,10,16),y=c(5,5,15,15)),
-                         list(x=c(0,16),y=c(15,15)),
-                         list(x=c(0,16),y=c(30,30))),
+      ranges      = list(c(0,max.riverwidth),c(0,max.ripparzonewidth)),
+      isolines    = list(list(x=c(0,max.riverwidth),y=c(0,0)),
+                         list(x=c(0,1.5,10,max.riverwidth),y=c(5,5,15,15)),
+                         list(x=c(0,max.riverwidth),y=c(15,15)),
+                         list(x=c(0,max.riverwidth),y=c(max.ripparzonewidth,max.ripparzonewidth))),
       u           = c(0.0,0.6,1.0,1.0),
       lead        = 1,
       utility     = FALSE,
       required    = FALSE,
       col         = col)
   
-  # Uferbereichsbreite left width widthvar=none
+  # Uferbereichsbreite left width widthvar=none:
   
   riparzone_left_width_novar <-
     utility.endnode.intpol2d.create(
       name.node   = ecoval.translate("N_morphol_riparzone_left_width_novar",dict),
       name.attrib = c(ecoval.translate("A_morphol_riverbed_width_m",dict),
                       ecoval.translate("A_morphol_riparzone_width_left_m",dict)),
-      ranges      = list(c(0,16),c(0,30)),
-      isolines    = list(list(x=c(0,16),y=c(0,0)),
-                         list(x=c(0,1,7.5,16),y=c(5,5,15,15)),
-                         list(x=c(0,16),y=c(15,15)),
-                         list(x=c(0,16),y=c(30,30))),
+      ranges      = list(c(0,max.riverwidth),c(0,max.ripparzonewidth)),
+      isolines    = list(list(x=c(0,max.riverwidth),y=c(0,0)),
+                         list(x=c(0,1,7.5,max.riverwidth),y=c(5,5,15,15)),
+                         list(x=c(0,max.riverwidth),y=c(15,15)),
+                         list(x=c(0,max.riverwidth),y=c(max.ripparzonewidth,max.ripparzonewidth))),
       u           = c(0.0,0.6,1.0,1.0),
       lead        = 1,
       utility     = FALSE,
       required    = FALSE,
       col         = col)
   
-  # Uferbereichsbreite right width widthvar=high
+  # Uferbereichsbreite right width widthvar=high:
   
   riparzone_right_width_highvar <-
     utility.endnode.intpol2d.create(
       name.node   = ecoval.translate("N_morphol_riparzone_right_width_highvar",dict),
       name.attrib = c(ecoval.translate("A_morphol_riverbed_width_m",dict),
                       ecoval.translate("A_morphol_riparzone_width_right_m",dict)),
-      ranges      = list(c(0,16),c(0,30)),
-      isolines    = list(list(x=c(0,16),y=c(0,0)),
-                         list(x=c(0,2,15,16),y=c(5,5,15,15)),
-                         list(x=c(0,16),y=c(15,15)),
-                         list(x=c(0,16),y=c(30,30))),
+      ranges      = list(c(0,max.riverwidth),c(0,max.ripparzonewidth)),
+      isolines    = list(list(x=c(0,max.riverwidth),y=c(0,0)),
+                         list(x=c(0,2,15,max.riverwidth),y=c(5,5,15,15)),
+                         list(x=c(0,max.riverwidth),y=c(15,15)),
+                         list(x=c(0,max.riverwidth),y=c(max.ripparzonewidth,max.ripparzonewidth))),
       u           = c(0.0,0.6,1.0,1.0),
       lead        = 1,
       utility     = FALSE,
       required    = FALSE,
       col         = col)
   
-  # Uferbereichsbreite right width widthvar=moderate
+  # Uferbereichsbreite right width widthvar=moderate:
   
   riparzone_right_width_moderatevar <-
     utility.endnode.intpol2d.create(
       name.node   = ecoval.translate("N_morphol_riparzone_right_width_moderatevar",dict),
       name.attrib = c(ecoval.translate("A_morphol_riverbed_width_m",dict),
                       ecoval.translate("A_morphol_riparzone_width_right_m",dict)),
-      ranges      = list(c(0,16),c(0,30)),
-      isolines    = list(list(x=c(0,16),y=c(0,0)),
-                         list(x=c(0,1.5,10,16),y=c(5,5,15,15)),
-                         list(x=c(0,16),y=c(15,15)),
-                         list(x=c(0,16),y=c(30,30))),
+      ranges      = list(c(0,max.riverwidth),c(0,max.ripparzonewidth)),
+      isolines    = list(list(x=c(0,max.riverwidth),y=c(0,0)),
+                         list(x=c(0,1.5,10,max.riverwidth),y=c(5,5,15,15)),
+                         list(x=c(0,max.riverwidth),y=c(15,15)),
+                         list(x=c(0,max.riverwidth),y=c(max.ripparzonewidth,max.ripparzonewidth))),
       u           = c(0.0,0.6,1.0,1.0),
       lead         = 1,
       utility       = FALSE,
       required    = FALSE,
       col           = col)
   
-  # Uferbereichsbreite right width widthvar=none
+  # Uferbereichsbreite right width widthvar=none:
   
   riparzone_right_width_novar <-
     utility.endnode.intpol2d.create(
       name.node   = ecoval.translate("N_morphol_riparzone_right_width_novar",dict),
       name.attrib = c(ecoval.translate("A_morphol_riverbed_width_m",dict),
                       ecoval.translate("A_morphol_riparzone_width_right_m",dict)),
-      ranges      = list(c(0,16),c(0,30)),
-      isolines    = list(list(x=c(0,16),y=c(0,0)),
-                         list(x=c(0,1,7.5,16),y=c(5,5,15,15)),
-                         list(x=c(0,16),y=c(15,15)),
-                         list(x=c(0,16),y=c(30,30))),
+      ranges      = list(c(0,max.riverwidth),c(0,max.ripparzonewidth)),
+      isolines    = list(list(x=c(0,max.riverwidth),y=c(0,0)),
+                         list(x=c(0,1,7.5,max.riverwidth),y=c(5,5,15,15)),
+                         list(x=c(0,max.riverwidth),y=c(15,15)),
+                         list(x=c(0,max.riverwidth),y=c(max.ripparzonewidth,max.ripparzonewidth))),
       u           = c(0.0,0.6,1.0,1.0),
       lead        = 1,
       utility     = FALSE,
       required    = FALSE,
       col         = col)
   
-  # Uferbereichsbreite left width
+  # Uferbereichsbreite left width:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_widthvar_class_high",dict),
                        ecoval.translate("L_morphol_widthvar_class_moderate",dict),
@@ -687,7 +476,7 @@ msk.morphol.1998.create <- function(language     = "English",
       utility       = FALSE,
       col           = col)
   
-  # Uferbereichsbreite right width
+  # Uferbereichsbreite right width:
   
   comb <- data.frame(c(ecoval.translate("L_morphol_widthvar_class_high",dict),
                        ecoval.translate("L_morphol_widthvar_class_moderate",dict),
@@ -704,7 +493,7 @@ msk.morphol.1998.create <- function(language     = "English",
       utility       = FALSE,
       col           = col)
   
-  # Uferbereichsvegetation left (discrete attribute)
+  # Uferbereichsvegetation left:
   
   comb <-  data.frame(c(ecoval.translate("L_morphol_riparzone_veg_class_natural",dict),
                         ecoval.translate("L_morphol_riparzone_veg_class_seminatural",dict),
@@ -719,7 +508,7 @@ msk.morphol.1998.create <- function(language     = "English",
       utility       = FALSE,
       col           = col)
   
-  # Uferbereichsvegetation right (discrete attribute)
+  # Uferbereichsvegetation right:
   
   comb <-  data.frame(c(ecoval.translate("L_morphol_riparzone_veg_class_natural",dict),
                         ecoval.translate("L_morphol_riparzone_veg_class_seminatural",dict),
@@ -734,7 +523,7 @@ msk.morphol.1998.create <- function(language     = "English",
       utility       = FALSE,
       col           = col)
   
-  # Uferbereich left
+  # Uferbereich left:
   
   riparzone_left <-
     utility.aggregation.create(
@@ -745,7 +534,7 @@ msk.morphol.1998.create <- function(language     = "English",
       required  = FALSE,
       col       = col)
   
-  # Uferbereich right
+  # Uferbereich right:
   
   riparzone_right <-
     utility.aggregation.create(
@@ -756,7 +545,7 @@ msk.morphol.1998.create <- function(language     = "English",
       required  = FALSE,
       col       = col)
   
-  # Uferbereich
+  # Uferbereich:
   
   riparzone <-
     utility.aggregation.create(
@@ -767,7 +556,7 @@ msk.morphol.1998.create <- function(language     = "English",
       required  = TRUE,
       col       = col)
   
-  # Oekomorphologie
+  # Oekomorphologie:
   
   comb <-  data.frame(c(ecoval.translate("L_morphol_coverage_class_covered",dict),
                         ecoval.translate("L_morphol_coverage_class_uncovered",dict)))
